@@ -1,6 +1,6 @@
 import pytest
 
-from onfido import ApiException, Document, DocumentsList
+from onfido import ApiException, Document, DocumentsList, DocumentTypes
 from tests.conftest import create_applicant, upload_document
 
 
@@ -17,7 +17,7 @@ def document(onfido_api, applicant_id):
 def test_create_document(applicant_id, document):
     assert document is not None
     assert document.applicant_id == applicant_id
-    assert document.type == "passport"
+    assert document.type == DocumentTypes.PASSPORT
     assert document.side == "front"
     assert isinstance(document, Document)
 
